pub struct Note {
pub paying_key: PayingKey,
pub value: Amount<NonNegative>,
pub rho: NullifierSeed,
pub rcm: CommitmentRandomness,
pub memo: Memo,
}Expand description
A Note represents that a value is spendable by the recipient who holds the spending key corresponding to a given shielded payment address.
Fields
paying_key: PayingKeyThe paying key of the recipient’s shielded payment address
value: Amount<NonNegative>An integer representing the value of the note in zatoshi (1 ZEC = 10^8 zatoshi)
rho: NullifierSeedInput to PRF^nf to derive the nullifier of the note
rcm: CommitmentRandomnessA random commitment trapdoor
memo: MemoThe note memo, after decryption